@@ -18,6 +18,7 @@
 import matplotlib.pyplot as plt
 import pandas as pd
 import numpy as np
+from adjustText import adjust_text
 
 from sciviso import Vis
 
@@ -27,7 +28,10 @@ class Volcanoplot(Vis):
     def __init__(self, df: pd.DataFrame, log_fc: str, p_val: str, label_column: str, title='',
                  xlabel='', ylabel='', invert=False, p_val_cutoff=0.05,
                  log_fc_cuttoff=2, label_big_sig=False, colours=None, offset=None,
-                 values_to_label=None, max_labels=20, values_colours=None):
+                 text_colours=None, values_to_label=None, max_labels=20, values_colours=None,
+                 figsize=(3, 3), title_font_size=8, label_font_size=6, title_font_weight=700):
+        super().__init__(df, figsize=figsize, title_font_size=title_font_size, label_font_size=label_font_size,
+                         title_font_weight=title_font_weight)
         super().__init__(df)
         self.log_fc = log_fc
         self.p_val = p_val
@@ -52,32 +56,33 @@ class Volcanoplot(Vis):
         self.title = title
         self.max_labels = max_labels
         self.values_colours = values_colours or {}
+        self.text_colours = text_colours or {}
 
     def add_scatter_and_annotate(self, fig: plt, x_all: np.array, y_all: np.array,
                                  colour: str, idxs: np.array, annotate=False):
         x = x_all[idxs]
         y = y_all[idxs]
-        ax = fig.scatter(x, y, c=colour, alpha=self.opacity)
+        ax = fig.scatter(x, y, c=colour, alpha=self.opacity, s=20)
 
         # Check if we want to annotate any of these with their gene IDs
+
         if self.values_to_label is not None:
+            texts = []
             labels = self.df[self.label_column].values[idxs]
             for i, name in enumerate(labels):
                 if name in self.values_to_label:
                     lbl_bg = self.values_colours.get(name)
-                    fig.annotate(name, (x[i], y[i]),
-                                 xytext=(0, 10),
-                                 textcoords='offset points', ha='center', va='bottom',
-                                 bbox=dict(boxstyle='round,pad=0.5',
-                                           fc=lbl_bg, alpha=0.5)
-                                 )
+                    color = self.text_colours.get(name)
+                    texts.append(fig.text(x[i], y[i], name, color=color, fontsize=6,
+                                          bbox=dict(fc=lbl_bg, alpha=1.0)))
+            adjust_text(texts, force_text=2.0)
         # Check if the user wants these labeled
         if self.label_big_sig and annotate:
             # If they do have a limit on the number of ones we show (i.e. we don't want 10000 gene names...)
             max_values = -1 * self.max_labels
             if len(y) < self.max_labels:
                 max_values = -1 * (len(y) - 1)
-            most_sig_idxs = np.argpartition(y, max_values)[max_values: ]
+            most_sig_idxs = np.argpartition(y, max_values)[max_values:]
             labels = self.df[self.label_column].values[idxs][most_sig_idxs]
             x = x[most_sig_idxs]
             y = y[most_sig_idxs]
@@ -87,7 +92,7 @@ class Volcanoplot(Vis):
                              xytext=(0, 10),
                              textcoords='offset points', ha='center', va='bottom',
                              bbox=dict(boxstyle='round,pad=0.5',
-                             fc='white', alpha=0.2)
+                                       fc='white', alpha=0.2)
                              )
         return ax
 
@@ -115,37 +120,25 @@ class Volcanoplot(Vis):
         if self.invert:
             x = -1 * np.log10(self.df[self.p_val].values + self.offset)
             y = self.df[self.log_fc].values
-
-        ns_small_pos_logfc = np.where((p_val_np > self.p_val_cutoff) & (np.abs(log_fc_np) < self.log_fc_cuttoff)
-                                & (log_fc_np > 0))
-        ns_big_pos_logfc = np.where((p_val_np > self.p_val_cutoff) & (np.abs(log_fc_np) >= self.log_fc_cuttoff)
-                               & (log_fc_np > 0))
         sig_small_pos_logfc = np.where((p_val_np <= self.p_val_cutoff) & (np.abs(log_fc_np) < self.log_fc_cuttoff)
-                                & (log_fc_np > 0))
+                                       & (log_fc_np > 0))
         sig_big_pos_logfc = np.where((p_val_np <= self.p_val_cutoff) & (np.abs(log_fc_np) >= self.log_fc_cuttoff)
-                                & (log_fc_np > 0))
+                                     & (log_fc_np > 0))
 
-        ns_small_neg_logfc = np.where((p_val_np > self.p_val_cutoff) & (np.abs(log_fc_np) < self.log_fc_cuttoff)
-                                & (log_fc_np <= 0))
-        ns_big_neg_logfc = np.where((p_val_np > self.p_val_cutoff) & (np.abs(log_fc_np) >= self.log_fc_cuttoff)
-                               & (log_fc_np <= 0))
         sig_small_neg_logfc = np.where((p_val_np <= self.p_val_cutoff) & (np.abs(log_fc_np) < self.log_fc_cuttoff)
-                                & (log_fc_np <= 0))
+                                       & (log_fc_np <= 0))
         sig_big_neg_logfc = np.where((p_val_np <= self.p_val_cutoff) & (np.abs(log_fc_np) >= self.log_fc_cuttoff)
-                                & (log_fc_np <= 0))
+                                     & (log_fc_np <= 0))
 
         # Plot the points
-        fig, ax = plt.subplots()
-
-        self.add_scatter_and_annotate(ax, x, y, self.colours['ns_small-pos-logFC'], ns_small_pos_logfc)
-        self.add_scatter_and_annotate(ax, x, y, self.colours['ns_big-pos-logFC'], ns_big_pos_logfc)
+        fig, ax = plt.subplots(figsize=(3, 3))
         self.add_scatter_and_annotate(ax, x, y, self.colours['sig_small-pos-logFC'], sig_small_pos_logfc)
         self.add_scatter_and_annotate(ax, x, y, self.colours['sig_big-pos-logFC'], sig_big_pos_logfc, annotate=True)
 
         # Negative
-        self.add_scatter_and_annotate(ax, x, y, self.colours['ns_small-neg-logFC'], ns_small_neg_logfc)
-        self.add_scatter_and_annotate(ax, x, y, self.colours['ns_big-neg-logFC'], ns_big_neg_logfc)
         self.add_scatter_and_annotate(ax, x, y, self.colours['sig_small-neg-logFC'], sig_small_neg_logfc)
         self.add_scatter_and_annotate(ax, x, y, self.colours['sig_big-neg-logFC'], sig_big_neg_logfc, annotate=True)
         self.add_labels()
+        ax.tick_params(labelsize=6)
+        self.set_ax_params(ax)
         return ax
